@@ -37,7 +37,7 @@ import org.apache.commons.pool2.TrackedUse;
  */
 public class AbandonedTrace implements TrackedUse, AutoCloseable {
 
-    static void add(AbandonedTrace receiver, AbandonedTrace trace) {
+    static void add(final AbandonedTrace receiver, final AbandonedTrace trace) {
         if (receiver != null) {
             receiver.addTrace(trace);
         }
@@ -158,7 +158,7 @@ public class AbandonedTrace implements TrackedUse, AutoCloseable {
      *            AbandonedTrace parent object.
      */
     private void init(final AbandonedTrace parent) {
-        AbandonedTrace.add(parent, this);
+        add(parent, this);
     }
 
     /**
