@@ -42,7 +42,7 @@ final class ConnectionFactoryFactory {
         final Properties connectionProperties = basicDataSource.getConnectionProperties();
         final String url = basicDataSource.getUrl();
         // Set up the driver connection factory we will use
-        final String user = basicDataSource.getUsername();
+        final String user = basicDataSource.getUserName();
         if (user != null) {
             connectionProperties.put(Constants.KEY_USER, user);
         } else {
