@@ -41,7 +41,7 @@ public class PoolingDriver implements Driver {
      *
      * @since 2.0
      */
-    private class PoolGuardConnectionWrapper extends DelegatingConnection<Connection> {
+    private final class PoolGuardConnectionWrapper extends DelegatingConnection<Connection> {
 
         private final ObjectPool<? extends Connection> pool;
 
@@ -87,14 +87,24 @@ public class PoolingDriver implements Driver {
     /** The map of registered pools. */
     protected static final HashMap<String, ObjectPool<? extends Connection>> pools = new HashMap<>();
 
-    /** My URL prefix */
+    /**
+     * The Apache Commons connection string prefix {@value}.
+     */
     public static final String URL_PREFIX = "jdbc:apache:commons:dbcp:";
 
+    /**
+     * The String length of {@link #URL_PREFIX}.
+     */
     protected static final int URL_PREFIX_LEN = URL_PREFIX.length();
 
-    // version numbers
+    /**
+     * Major version number.
+     */
     protected static final int MAJOR_VERSION = 1;
 
+    /**
+     * Minor version number.
+     */
     protected static final int MINOR_VERSION = 0;
 
     /** Controls access to the underlying connection */
@@ -147,7 +157,6 @@ public class PoolingDriver implements Driver {
     public Connection connect(final String url, final Properties info) throws SQLException {
         if (acceptsURL(url)) {
             final ObjectPool<? extends Connection> pool = getConnectionPool(url.substring(URL_PREFIX_LEN));
-
             try {
                 final Connection conn = pool.borrowObject();
                 if (conn == null) {
