@@ -84,7 +84,7 @@ final class ConnectionImpl extends DelegatingConnection<Connection> {
     }
 
     /**
-     * Get the delegated connection, if allowed.
+     * Gets the delegated connection, if allowed.
      *
      * @return the internal connection, or null if access is not allowed.
      * @see #isAccessToUnderlyingConnectionAllowed()
@@ -98,7 +98,7 @@ final class ConnectionImpl extends DelegatingConnection<Connection> {
     }
 
     /**
-     * Get the innermost connection, if allowed.
+     * Gets the innermost connection, if allowed.
      *
      * @return the innermost internal connection, or null if access is not allowed.
      * @see #isAccessToUnderlyingConnectionAllowed()
@@ -111,6 +111,15 @@ final class ConnectionImpl extends DelegatingConnection<Connection> {
         return null;
     }
 
+    /**
+     * Package-private for tests.
+     *
+     * @return the PooledConnectionImpl.
+     */
+    PooledConnectionImpl getPooledConnectionImpl() {
+        return pooledConnection;
+    }
+
     /**
      * If false, getDelegate() and getInnermostDelegate() will return null.
      *
@@ -245,6 +254,10 @@ final class ConnectionImpl extends DelegatingConnection<Connection> {
         }
     }
 
+    //
+    // Methods for accessing the delegate connection
+    //
+
     /**
      * If pooling of {@code PreparedStatement}s is turned on in the {@link DriverAdapterCPDS}, a pooled object may
      * be returned, otherwise delegate to the wrapped JDBC 1.x {@link java.sql.Connection}.
@@ -265,10 +278,6 @@ final class ConnectionImpl extends DelegatingConnection<Connection> {
         }
     }
 
-    //
-    // Methods for accessing the delegate connection
-    //
-
     @Override
     public PreparedStatement prepareStatement(final String sql, final int resultSetType, final int resultSetConcurrency,
             final int resultSetHoldability) throws SQLException {
