@@ -34,6 +34,13 @@ import org.junit.jupiter.api.Test;
  */
 public class TestBasicDataSourceMXBean {
 
+    public static void testMXBeanCompliance(final Class<?> clazz) throws OperationsException {
+        assertTrue(JMX.isMXBeanInterface(clazz));
+        final MBeanServer server = ManagementFactory.getPlatformMBeanServer();
+        final ObjectName objectName = ObjectName.getInstance("com.sun.management:type=DiagnosticCommand");
+        JMX.newMBeanProxy(server, objectName, clazz, true);
+    }
+
     private final BasicDataSourceMXBean bean = new BasicDataSourceMXBean() {
 
         @Override
@@ -71,6 +78,11 @@ public class TestBasicDataSourceMXBean {
             return 0;
         }
 
+        @Override
+        public String[] getDisconnectionIgnoreSqlCodesAsArray() {
+            return null;
+        }
+
         @Override
         public String[] getDisconnectionSqlCodesAsArray() {
             return null;
@@ -257,11 +269,4 @@ public class TestBasicDataSourceMXBean {
     public void testMXBeanCompliance() throws OperationsException {
         testMXBeanCompliance(BasicDataSourceMXBean.class);
     }
-
-    public static void testMXBeanCompliance(Class<?> clazz) throws OperationsException {
-        assertTrue(JMX.isMXBeanInterface(clazz));
-        final MBeanServer server = ManagementFactory.getPlatformMBeanServer();
-        final ObjectName objectName = ObjectName.getInstance("com.sun.management:type=DiagnosticCommand");
-        JMX.newMBeanProxy(server, objectName, clazz, true);
-    }
 }
