@@ -53,8 +53,6 @@ import org.junit.jupiter.api.Test;
  */
 public abstract class TestConnectionPool {
 
-    private static final Duration MAX_WAIT_DURATION = Duration.ofMillis(100);
-
     protected class PoolTest implements Runnable {
         /**
          * The number of milliseconds to hold onto a database connection
@@ -165,38 +163,38 @@ public abstract class TestConnectionPool {
         }
     }
 
-    class TestThread implements Runnable {
-        final java.util.Random _random = new java.util.Random();
-        boolean _complete;
-        boolean _failed;
-        int _iter = 100;
-        int _delay = 50;
+    final class TestThread implements Runnable {
+        final Random random = new Random();
+        boolean complete;
+        boolean failed;
+        int iter = 100;
+        int delay = 50;
 
         public TestThread() {
         }
 
         public TestThread(final int iter) {
-            _iter = iter;
+            this.iter = iter;
         }
 
         public TestThread(final int iter, final int delay) {
-            _iter = iter;
-            _delay = delay;
+            this.iter = iter;
+            this.delay = delay;
         }
 
         public boolean complete() {
-            return _complete;
+            return complete;
         }
 
         public boolean failed() {
-            return _failed;
+            return failed;
         }
 
         @Override
         public void run() {
-            for (int i = 0; i < _iter; i++) {
+            for (int i = 0; i < iter; i++) {
                 try {
-                    Thread.sleep(_random.nextInt(_delay));
+                    Thread.sleep(random.nextInt(delay));
                 } catch (final Exception e) {
                     // ignored
                 }
@@ -204,23 +202,25 @@ public abstract class TestConnectionPool {
                         PreparedStatement stmt = conn.prepareStatement("select 'literal', SYSDATE from dual");
                         ResultSet rset = stmt.executeQuery()) {
                     try {
-                        Thread.sleep(_random.nextInt(_delay));
+                        Thread.sleep(random.nextInt(delay));
                     } catch (final Exception ignore) {
                         // ignored
                     }
                 } catch (final Exception e) {
                     e.printStackTrace();
-                    _failed = true;
-                    _complete = true;
+                    failed = true;
+                    complete = true;
                     break;
                 }
             }
-            _complete = true;
+            complete = true;
         }
     }
 
+    private static final Duration MAX_WAIT_DURATION = Duration.ofMillis(100);
+
     private static final boolean DISPLAY_THREAD_DETAILS=
-            Boolean.parseBoolean(System.getProperty("TestConnectionPool.display.thread.details", "false"));
+    Boolean.getBoolean("TestConnectionPool.display.thread.details");
     // To pass this to a Maven test, use:
     // mvn test -DargLine="-DTestConnectionPool.display.thread.details=true"
     // @see https://issues.apache.org/jira/browse/SUREFIRE-121
@@ -232,7 +232,6 @@ public abstract class TestConnectionPool {
     /** Connections opened during the course of a test */
     protected final Stack<Connection> connectionStack = new Stack<>();
 
-    // ----------- Utility Methods ---------------------------------
 
     protected void assertBackPointers(final Connection conn, final Statement statement) throws SQLException {
         assertFalse(conn.isClosed());
@@ -265,7 +264,6 @@ public abstract class TestConnectionPool {
                     "resultSet.getStatement() should return the exact same statement instance that was used to create the result set");
         }
 
-
         resultSet.getStatement().getConnection().close();
         assertTrue(conn.isClosed());
         assertTrue(isClosed(statement));
@@ -461,9 +459,9 @@ public abstract class TestConnectionPool {
         }
     }
 
-    /** 
+    /**
      * Acquires a new connection and push it onto the connections stack.
-     * 
+     *
      * @return a new connection.
      * @throws Exception Defined in subclasses.
      */
@@ -965,6 +963,6 @@ public abstract class TestConnectionPool {
     }
 
     long timeStampMillis() {
-        return System.currentTimeMillis();// JVM 1.5+ System.nanoTime() / 1000000;
+        return System.currentTimeMillis(); // JVM 1.5+ System.nanoTime() / 1000000;
     }
 }
