@@ -26,9 +26,8 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
+import java.util.Random;
 
-import org.apache.commons.logging.LogFactory;
-import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
@@ -37,21 +36,18 @@ import org.junit.jupiter.api.Test;
  */
 public class TestParallelCreationWithNoIdle  {
 
-
-    class TestThread extends Thread {
-        final java.util.Random _random = new java.util.Random();
+    final class TestThread extends Thread {
+        final Random random = new Random();
         final int iter;
         final int delay;
         final int delayAfter;
 
-
         public TestThread(final int iter, final int delay, final int delayAfter) {
             this.iter = iter;
             this.delay = delay;
             this.delayAfter = delayAfter;
         }
 
-
         @Override
         public void run() {
             // System.out.println("Thread started " + Thread.currentThread().toString());
@@ -77,7 +73,7 @@ public class TestParallelCreationWithNoIdle  {
                 return;
             }
             try {
-                Thread.sleep(_random.nextInt(timeMax));
+                Thread.sleep(random.nextInt(timeMax));
             } catch (final Exception e) {
                 // ignored
             }
@@ -85,12 +81,6 @@ public class TestParallelCreationWithNoIdle  {
     }
     private static final String CATALOG = "test catalog";
 
-    @BeforeAll
-    public static void setUpClass() {
-        // register a custom logger which supports inspection of the log messages
-        LogFactory.getFactory().setAttribute("org.apache.commons.logging.Log", "org.apache.commons.dbcp2.StackMessageLog");
-    }
-
     protected BasicDataSource ds;
 
     @BeforeEach
@@ -121,8 +111,6 @@ public class TestParallelCreationWithNoIdle  {
         ds.setJmxName("org.apache.commons.dbcp2:name=test");
     }
 
-
-
     /**
      * Fire up 100 Threads but only have 10 maxActive and forcedBlock.
      * See
