@@ -17,12 +17,15 @@
 package org.apache.commons.dbcp2;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.fail;
 
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.ArrayList;
+import java.util.Arrays;
 
 import javax.management.OperationsException;
 
@@ -41,13 +44,10 @@ public class TestPoolableConnection {
     @BeforeEach
     public void setUp() throws Exception {
         final PoolableConnectionFactory factory = new PoolableConnectionFactory(
-                new DriverConnectionFactory(
-                        new TesterDriver(),"jdbc:apache:commons:testdriver", null),
-                null);
+                new DriverConnectionFactory(new TesterDriver(), "jdbc:apache:commons:testdriver", null), null);
         factory.setDefaultAutoCommit(Boolean.TRUE);
         factory.setDefaultReadOnly(Boolean.TRUE);
 
-
         pool = new GenericObjectPool<>(factory);
         factory.setPool(pool);
     }
@@ -90,6 +90,27 @@ public class TestPoolableConnection {
         assertEquals(0, pool.getNumActive(), "There should now be zero active objects in the pool");
     }
 
+    @Test
+    public void testDisconnectionIgnoreSqlCodes() throws Exception {
+        pool.setTestOnReturn(true);
+        final PoolableConnectionFactory factory = (PoolableConnectionFactory) pool.getFactory();
+        factory.setFastFailValidation(true);
+        factory.setDisconnectionIgnoreSqlCodes(Arrays.asList("08S02", "08007"));
+
+        final PoolableConnection conn = pool.borrowObject();
+        final TesterConnection nativeConnection = (TesterConnection) conn.getInnermostDelegate();
+
+        // set up non-fatal exception
+        nativeConnection.setFailure(new SQLException("Non-fatal connection error.", "08S02"));
+        assertThrows(SQLException.class, conn::createStatement);
+        nativeConnection.setFailure(null);
+
+        // verify that non-fatal connection is returned to the pool
+        conn.close();
+        assertEquals(0, pool.getNumActive(), "The pool should have no active connections");
+        assertEquals(1, pool.getNumIdle(), "The pool should have one idle connection");
+    }
+
     @Test
     public void testFastFailValidation() throws Exception {
         pool.setTestOnReturn(true);
@@ -149,14 +170,9 @@ public class TestPoolableConnection {
 
         // Set up fatal exception
         nativeConnection.setFailure(new SQLException("Fatal connection error.", "XXX"));
-
-        try {
-            conn.createStatement();
-            fail("Should throw SQL exception.");
-        } catch (final SQLException ignored) {
-            // cleanup failure
-            nativeConnection.setFailure(null);
-        }
+        assertThrows(SQLException.class, conn::createStatement);
+        // cleanup failure
+        nativeConnection.setFailure(null);
 
         // verify that bad connection does not get returned to the pool
         conn.close();  // testOnReturn triggers validate, which should fail
@@ -164,6 +180,30 @@ public class TestPoolableConnection {
         assertEquals(0, pool.getNumIdle(), "The pool should have no idle connections");
     }
 
+    @Test
+    public void testIsDisconnectionSqlExceptionStackOverflow() throws Exception {
+        final int maxDeep = 100_000;
+        final SQLException rootException = new SQLException("Data truncated", "22001");
+        SQLException parentException = rootException;
+        for (int i = 0; i <= maxDeep; i++) {
+            final SQLException childException = new SQLException("Data truncated: " + i, "22001");
+            parentException.setNextException(childException);
+            parentException = childException;
+        }
+        final Connection conn = pool.borrowObject();
+        assertFalse(((PoolableConnection) conn).isDisconnectionSqlException(rootException));
+        assertFalse(((PoolableConnection) conn).isFatalException(rootException));
+    }
+
+    /**
+     * Tests if the {@link PoolableConnectionMXBean} interface is a valid MXBean
+     * interface.
+     */
+    @Test
+    public void testMXBeanCompliance() throws OperationsException {
+       TestBasicDataSourceMXBean.testMXBeanCompliance(PoolableConnectionMXBean.class);
+    }
+
     // Bugzilla Bug 33591: PoolableConnection leaks connections if the
     // delegated connection closes itself.
     @Test
@@ -189,28 +229,4 @@ public class TestPoolableConnection {
 
         assertEquals(0, pool.getNumActive(), "The pool should have no active connections");
     }
-
-    @Test
-    public void testIsDisconnectionSqlExceptionStackOverflow() throws Exception {
-        final int maxDeep = 100_000;
-        final SQLException rootException = new SQLException("Data truncated", "22001");
-        SQLException parentException = rootException;
-        for (int i = 0; i <= maxDeep; i++) {
-            final SQLException childException = new SQLException("Data truncated: " + i, "22001");
-            parentException.setNextException(childException);
-            parentException = childException;
-        }
-        final Connection conn = pool.borrowObject();
-        assertEquals(false, ((PoolableConnection) conn).isDisconnectionSqlException(rootException));
-        assertEquals(false, ((PoolableConnection) conn).isFatalException(rootException));
-    }
-
-    /**
-     * Tests if the {@link PoolableConnectionMXBean} interface is a valid MXBean
-     * interface.
-     */
-    @Test
-    public void testMXBeanCompliance() throws OperationsException {
-       TestBasicDataSourceMXBean.testMXBeanCompliance(PoolableConnectionMXBean.class);
-    }
 }
