@@ -19,6 +19,7 @@ package org.apache.commons.dbcp2;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
+import java.sql.SQLException;
 import java.time.Duration;
 
 import org.apache.commons.pool2.impl.GenericKeyedObjectPool;
@@ -168,4 +169,19 @@ public class TestPoolingConnection {
             assertEquals(resultSetHoldability, testStatement.getResultSetHoldability());
         }
     }
+
+    /**
+     * Tests DBCP-596 PoolingConnection.toString() causes StackOverflowError.
+     */
+    @Test
+    public void testToStringStackOverflow() throws SQLException {
+        // Also tests a possible NullPointerException in PoolingConnection.close()
+        try (PoolingConnection conn = new PoolingConnection(null)) {
+            final GenericKeyedObjectPoolConfig<DelegatingPreparedStatement> config = new GenericKeyedObjectPoolConfig<>();
+            try (GenericKeyedObjectPool<PStmtKey, DelegatingPreparedStatement> stmtPool = new GenericKeyedObjectPool<>(conn, config)) {
+                conn.setStatementPool(stmtPool);
+            }
+            conn.toString();
+        }
+    }
 }
