@@ -27,8 +27,8 @@ import java.util.Properties;
 import java.util.logging.Logger;
 
 /**
- * Mock object implementing the <code>java.sql.Driver</code> interface.
- * Returns <code>TestConnection</code>'s from getConnection methods.
+ * Mock object implementing the {@link Driver} interface.
+ * Returns {@code TestConnection}'s from getConnection methods.
  * Valid user name, password combinations are:
  *
  * <table summary="valid credentials">
@@ -40,7 +40,11 @@ import java.util.logging.Logger;
  * </table>
  */
 public class TesterDriver implements Driver {
+
+    static TesterDriver INSTANCE = new TesterDriver();
+
     private static final Properties validUserPasswords = new Properties();
+
     static {
         try {
             DriverManager.registerDriver(new TesterDriver());
