@@ -90,7 +90,9 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         ((PerUserPoolDataSource) ds).close();
     }
 
-    // See DBCP-8
+    /**
+     * See DBCP-8
+     */
     @Test
     public void testChangePassword() throws Exception {
         assertThrows(SQLException.class, () -> ds.getConnection(user, "bay"));
@@ -99,28 +101,23 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         final Connection con3 = ds.getConnection(user, "bar");
         con1.close();
         con2.close();
-        TesterDriver.addUser(user,"bay"); // change the user/password setting
+        TesterDriver.addUser(user, "bay"); // change the user/password setting
         try {
             final Connection con4 = ds.getConnection(user, "bay"); // new password
             // Idle instances with old password should have been cleared
-            assertEquals(0, ((PerUserPoolDataSource) ds).getNumIdle(user),
-                    "Should be no idle connections in the pool");
+            assertEquals(0, ((PerUserPoolDataSource) ds).getNumIdle(user), "Should be no idle connections in the pool");
             con4.close();
             // Should be one idle instance with new pwd
-            assertEquals(1, ((PerUserPoolDataSource) ds).getNumIdle(user),
-                    "Should be one idle connection in the pool");
-            try (Connection c = ds.getConnection(user, "bar")) { // old password
-                fail("Should have generated SQLException");
-            } catch (final SQLException expected) {
+            assertEquals(1, ((PerUserPoolDataSource) ds).getNumIdle(user), "Should be one idle connection in the pool");
+            // old password
+            assertThrows(SQLException.class, () -> ds.getConnection(user, "bar"), "Should have generated SQLException");
+            try (Connection con5 = ds.getConnection(user, "bay")) { // take the idle one
+                con3.close(); // Return a connection with the old password
+                ds.getConnection(user, "bay").close(); // will try bad returned connection and destroy it
+                assertEquals(1, ((PerUserPoolDataSource) ds).getNumIdle(user), "Should be one idle connection in the pool");
             }
-            final Connection con5 = ds.getConnection(user, "bay"); // take the idle one
-            con3.close(); // Return a connection with the old password
-            ds.getConnection(user, "bay").close();  // will try bad returned connection and destroy it
-            assertEquals(1, ((PerUserPoolDataSource) ds).getNumIdle(user),
-                    "Should be one idle connection in the pool");
-            con5.close();
         } finally {
-            TesterDriver.addUser(user,"bar");
+            TesterDriver.addUser(user, "bar");
         }
     }
 
@@ -650,6 +647,45 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertNull(ds.getPerUserDefaultTransactionIsolation("missingkey"));
     }
 
+    @Test
+    public void testPerUserDurationBetweenEvictionRunsMapInitialized() {
+        final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
+        Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
+        assertEquals(0L, ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
+        assertEquals(Duration.ZERO, ds.getPerUserDurationBetweenEvictionRuns("key"));
+        values = new HashMap<>();
+        values.put("anonymous", Duration.ZERO);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
+        assertEquals(ds.getDefaultTimeBetweenEvictionRunsMillis(), ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
+        assertEquals(ds.getDefaultDurationBetweenEvictionRuns(), ds.getPerUserDurationBetweenEvictionRuns("key"));
+        assertEquals(0L, ds.getPerUserTimeBetweenEvictionRunsMillis("anonymous"));
+        assertEquals(Duration.ZERO, ds.getPerUserDurationBetweenEvictionRuns("anonymous"));
+    }
+
+    // -- per user default transaction isolation
+
+    @Test
+    public void testPerUserDurationBetweenEvictionRunsMapNotInitialized() {
+        final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", DURATION_1_MILLISECOND);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
+        assertEquals(1L, ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
+        assertEquals(DURATION_1_MILLISECOND, ds.getPerUserDurationBetweenEvictionRuns("key"));
+    }
+
+    @Test
+    public void testPerUserDurationBetweenEvictionRunsMapNotInitializedMissingKey() {
+        final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
+        assertEquals(ds.getDefaultTimeBetweenEvictionRunsMillis(), ds.getPerUserTimeBetweenEvictionRunsMillis("missingkey"));
+        assertEquals(ds.getDefaultDurationBetweenEvictionRuns(), ds.getPerUserDurationBetweenEvictionRuns("missingkey"));
+    }
+
     @Test
     public void testPerUserEvictionPolicyClassNameMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -664,8 +700,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals("bar", ds.getPerUserEvictionPolicyClassName("anonymous"));
     }
 
-    // -- per user default transaction isolation
-
     @Test
     public void testPerUserEvictionPolicyClassNameMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -694,6 +728,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals("bar", ds.getPerUserEvictionPolicyClassName("anotheruser"));
     }
 
+    // -- per user eviction policy class name
+
     @Test
     public void testPerUserEvictionPolicyClassNameWithUserMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -722,8 +758,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(Boolean.FALSE, ds.getPerUserLifo("anonymous"));
     }
 
-    // -- per user eviction policy class name
-
     @Test
     public void testPerUserLifoMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -752,6 +786,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(Boolean.FALSE, ds.getPerUserLifo("anotheruser"));
     }
 
+    // -- per user lifo
+
     @Test
     public void testPerUserLifoWithUserMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -780,8 +816,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) 0, (Integer) ds.getPerUserMaxIdle("anonymous"));
     }
 
-    // -- per user lifo
-
     @Test
     public void testPerUserMaxIdleMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -810,6 +844,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) 0, (Integer) ds.getPerUserMaxIdle("anotheruser"));
     }
 
+    // -- per user max idle
+
     @Test
     public void testPerUserMaxIdleWithUserMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -838,8 +874,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) 0, (Integer) ds.getPerUserMaxTotal("anonymous"));
     }
 
-    // -- per user max idle
-
     @Test
     public void testPerUserMaxTotalMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -925,6 +959,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(0L, ds.getPerUserMaxWaitMillis("anotheruser"));
     }
 
+    // -- per user max wait millis
+
     @Test
     @SuppressWarnings("deprecation")
     public void testPerUserMaxWaitMillisWithUserMapNotInitialized_Deprecated() {
@@ -990,8 +1026,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(0, tds.getNumIdle("u2"));
     }
 
-    // -- per user max wait millis
-
     @Test
     public void testPerUserMinEvictableIdleDurationMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1029,6 +1063,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultMinEvictableIdleDuration(), ds.getPerUserMinEvictableIdleDuration("missingkey"));
     }
 
+    // -- per user min evictable idle time millis
+
     @Test
     public void testPerUserMinEvictableIdleTimeMillisWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1053,8 +1089,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultMinEvictableIdleTimeMillis(), ds.getPerUserMinEvictableIdleTimeMillis("missingkey"));
     }
 
-    // -- per user min evictable idle time millis
-
     @Test
     public void testPerUserMinIdleMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1087,6 +1121,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) ds.getDefaultMinIdle(), (Integer) ds.getPerUserMinIdle("missingkey"));
     }
 
+    // -- per user min idle
+
     @Test
     public void testPerUserMinIdleWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1111,8 +1147,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) ds.getDefaultMinIdle(), (Integer) ds.getPerUserMinIdle("missingkey"));
     }
 
-    // -- per user min idle
-
     @Test
     public void testPerUserNumTestsPerEvictionRunMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1145,6 +1179,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) ds.getDefaultNumTestsPerEvictionRun(), (Integer) ds.getPerUserNumTestsPerEvictionRun("missingkey"));
     }
 
+    // -- per user num tests per eviction run
+
     @Test
     public void testPerUserNumTestsPerEvictionRunWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1169,8 +1205,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals((Integer) ds.getDefaultNumTestsPerEvictionRun(), (Integer) ds.getPerUserNumTestsPerEvictionRun("missingkey"));
     }
 
-    // -- per user num tests per eviction run
-
     @Test
     public void testPerUserSoftMinEvictableIdleDurationMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1208,6 +1242,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultSoftMinEvictableIdleDuration(), ds.getPerUserSoftMinEvictableIdleDuration("missingkey"));
     }
 
+    // -- per user soft min evictable idle time millis
+
     @Test
     public void testPerUserSoftMinEvictableIdleTimeMillisWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1232,8 +1268,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultSoftMinEvictableIdleTimeMillis(), ds.getPerUserSoftMinEvictableIdleTimeMillis("missingkey"));
     }
 
-    // -- per user soft min evictable idle time millis
-
     @Test
     public void testPerUserTestOnBorrowMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1266,6 +1300,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestOnBorrow(), ds.getPerUserTestOnBorrow("missingkey"));
     }
 
+    // -- per user test on borrow
+
     @Test
     public void testPerUserTestOnBorrowWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1290,8 +1326,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestOnBorrow(), ds.getPerUserTestOnBorrow("missingkey"));
     }
 
-    // -- per user test on borrow
-
     @Test
     public void testPerUserTestOnCreateMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1324,6 +1358,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestOnCreate(), ds.getPerUserTestOnCreate("missingkey"));
     }
 
+    // -- per user test on create
+
     @Test
     public void testPerUserTestOnCreateWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1348,8 +1384,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestOnCreate(), ds.getPerUserTestOnCreate("missingkey"));
     }
 
-    // -- per user test on create
-
     @Test
     public void testPerUserTestOnReturnMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1382,6 +1416,8 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestOnReturn(), ds.getPerUserTestOnReturn("missingkey"));
     }
 
+    // -- per user test on return
+
     @Test
     public void testPerUserTestOnReturnWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1406,8 +1442,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestOnReturn(), ds.getPerUserTestOnReturn("missingkey"));
     }
 
-    // -- per user test on return
-
     @Test
     public void testPerUserTestWhileIdleMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
@@ -1464,43 +1498,6 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestWhileIdle(), ds.getPerUserTestWhileIdle("missingkey"));
     }
 
-    @Test
-    public void testPerUserDurationBetweenEvictionRunsMapInitialized() {
-        final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        Map<String, Duration> values = new HashMap<>();
-        values.put("key", Duration.ZERO);
-        ds.setPerUserDurationBetweenEvictionRuns(values);
-        assertEquals(0L, ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
-        assertEquals(Duration.ZERO, ds.getPerUserDurationBetweenEvictionRuns("key"));
-        values = new HashMap<>();
-        values.put("anonymous", Duration.ZERO);
-        ds.setPerUserDurationBetweenEvictionRuns(values);
-        assertEquals(ds.getDefaultTimeBetweenEvictionRunsMillis(), ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
-        assertEquals(ds.getDefaultDurationBetweenEvictionRuns(), ds.getPerUserDurationBetweenEvictionRuns("key"));
-        assertEquals(0L, ds.getPerUserTimeBetweenEvictionRunsMillis("anonymous"));
-        assertEquals(Duration.ZERO, ds.getPerUserDurationBetweenEvictionRuns("anonymous"));
-    }
-
-    @Test
-    public void testPerUserDurationBetweenEvictionRunsMapNotInitialized() {
-        final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Duration> values = new HashMap<>();
-        values.put("key", DURATION_1_MILLISECOND);
-        ds.setPerUserDurationBetweenEvictionRuns(values);
-        assertEquals(1L, ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
-        assertEquals(DURATION_1_MILLISECOND, ds.getPerUserDurationBetweenEvictionRuns("key"));
-    }
-
-    @Test
-    public void testPerUserDurationBetweenEvictionRunsMapNotInitializedMissingKey() {
-        final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Duration> values = new HashMap<>();
-        values.put("key", Duration.ZERO);
-        ds.setPerUserDurationBetweenEvictionRuns(values);
-        assertEquals(ds.getDefaultTimeBetweenEvictionRunsMillis(), ds.getPerUserTimeBetweenEvictionRunsMillis("missingkey"));
-        assertEquals(ds.getDefaultDurationBetweenEvictionRuns(), ds.getPerUserDurationBetweenEvictionRuns("missingkey"));
-    }
-
     @Test
     public void testPerUserTimeBetweenEvictionRunsMillisWithUserMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
