@@ -47,27 +47,6 @@ import org.junit.jupiter.api.Test;
  */
 public class TestSharedPoolDataSource extends TestConnectionPool {
 
-    private static class CscbString extends AbstractPrepareCallCallback {
-        @Override
-        CallableStatement getCallableStatement() throws SQLException {
-            return conn.prepareCall("{call home()}");
-        }
-    }
-
-    private static class CscbStringIntInt extends AbstractPrepareCallCallback {
-        @Override
-        CallableStatement getCallableStatement() throws SQLException {
-            return conn.prepareCall("{call home()}", 0, 0);
-        }
-    }
-
-    private static class CscbStringIntIntInt extends AbstractPrepareCallCallback {
-        @Override
-        CallableStatement getCallableStatement() throws SQLException {
-            return conn.prepareCall("{call home()}", 0, 0, 0);
-        }
-    }
-
     /**
      * There are 3 different prepareCall statement methods so add a little complexity to reduce what would otherwise be lots
      * of copy and paste.
@@ -96,42 +75,63 @@ public class TestSharedPoolDataSource extends TestConnectionPool {
         }
     }
 
-    private static class PscbString extends AbstractPrepareStatementCallback {
+    private static final class CscbString extends AbstractPrepareCallCallback {
+        @Override
+        CallableStatement getCallableStatement() throws SQLException {
+            return conn.prepareCall("{call home()}");
+        }
+    }
+
+    private static final class CscbStringIntInt extends AbstractPrepareCallCallback {
+        @Override
+        CallableStatement getCallableStatement() throws SQLException {
+            return conn.prepareCall("{call home()}", 0, 0);
+        }
+    }
+
+    private static final class CscbStringIntIntInt extends AbstractPrepareCallCallback {
+        @Override
+        CallableStatement getCallableStatement() throws SQLException {
+            return conn.prepareCall("{call home()}", 0, 0, 0);
+        }
+    }
+
+    private static final class PscbString extends AbstractPrepareStatementCallback {
         @Override
         PreparedStatement prepareStatement() throws SQLException {
             return conn.prepareStatement("select * from dual");
         }
     }
 
-    private static class PscbStringInt extends AbstractPrepareStatementCallback {
+    private static final class PscbStringInt extends AbstractPrepareStatementCallback {
         @Override
         PreparedStatement prepareStatement() throws SQLException {
             return conn.prepareStatement("select * from dual", 0);
         }
     }
 
-    private static class PscbStringIntArray extends AbstractPrepareStatementCallback {
+    private static final class PscbStringIntArray extends AbstractPrepareStatementCallback {
         @Override
         PreparedStatement prepareStatement() throws SQLException {
             return conn.prepareStatement("select * from dual", ArrayUtils.EMPTY_INT_ARRAY);
         }
     }
 
-    private static class PscbStringIntInt extends AbstractPrepareStatementCallback {
+    private static final class PscbStringIntInt extends AbstractPrepareStatementCallback {
         @Override
         PreparedStatement prepareStatement() throws SQLException {
             return conn.prepareStatement("select * from dual", 0, 0);
         }
     }
 
-    private static class PscbStringIntIntInt extends AbstractPrepareStatementCallback {
+    private static final class PscbStringIntIntInt extends AbstractPrepareStatementCallback {
         @Override
         PreparedStatement prepareStatement() throws SQLException {
             return conn.prepareStatement("select * from dual", 0, 0, 0);
         }
     }
 
-    private static class PscbStringStringArray extends AbstractPrepareStatementCallback {
+    private static final class PscbStringStringArray extends AbstractPrepareStatementCallback {
         @Override
         PreparedStatement prepareStatement() throws SQLException {
             return conn.prepareStatement("select * from dual", ArrayUtils.EMPTY_STRING_ARRAY);
@@ -234,6 +234,7 @@ public class TestSharedPoolDataSource extends TestConnectionPool {
             tds.setDefaultTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
 
             @SuppressWarnings("resource")
+            final
             DataSource myDs = tds;
 
             try (Connection conn = ds.getConnection()) {
@@ -649,7 +650,7 @@ public class TestSharedPoolDataSource extends TestConnectionPool {
     @Test
     public void testSimple2() throws SQLException {
         {
-            Connection conn = ds.getConnection();
+            final Connection conn = ds.getConnection();
             assertNotNull(conn);
 
             try (PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
