@@ -53,7 +53,7 @@ import org.junit.jupiter.api.Test;
  */
 public class TestManagedConnection {
 
-    private class UncooperativeLocalXAConnectionFactory
+    private final class UncooperativeLocalXAConnectionFactory
         extends LocalXAConnectionFactory {
 
         public UncooperativeLocalXAConnectionFactory(final TransactionManager transactionManager, final ConnectionFactory connectionFactory) {
@@ -73,7 +73,7 @@ public class TestManagedConnection {
     /**
      * Transaction that always fails enlistResource.
      */
-    private static class UncooperativeTransaction
+    private static final class UncooperativeTransaction
         implements Transaction {
 
         private final Transaction wrappedTransaction;
@@ -125,7 +125,7 @@ public class TestManagedConnection {
         }
     }
 
-    private class UncooperativeTransactionRegistry
+    private final class UncooperativeTransactionRegistry
         extends TransactionRegistry {
 
         public UncooperativeTransactionRegistry(final TransactionManager transactionManager) {
@@ -196,7 +196,7 @@ public class TestManagedConnection {
     public void testConnectionReturnOnErrorWhenEnlistingXAResource() throws Exception {
         // see DBCP-433
         transactionManager.begin();
-        assertThrows(SQLException.class, () -> getConnection());
+        assertThrows(SQLException.class, this::getConnection);
         transactionManager.commit();
         assertEquals(1, pool.getBorrowedCount());
         // assertEquals(1, pool.getReturnedCount());
